% M_FILES, MMA Matlab Utilities
% Martinho Marta Almeida
% Physics department, Aveiro University, Portugal
% Freely available at:
%    http://neptuno.fis.ua.pt/~mma
% Email:
%    martinho@fis.ua.pt
% Date:
%    22-2-2005
%
% anim: Creation and manipulation of FLI/FLC animations
%   APPEND_ANIM    -   Join two FLI/FLC animations
%   DTA2FLI        -   Create FLI/FLC animations on Windows
%   FIXEDAR        -   Set figure PaperPosition as Position
%   GET_TIFF       -   Print current image
%   PPM2FLI        -   Create FLI/FLC animations on UNIX like machines
%   RESIZE_ANIM    -   Resize FLI/FLC animation
%   TIFF2PPM       -   Convert image (tif) to another (ppm)
%
% img: Creation and manipulation of graphics
%   AUTO_COLOR     -   Set different colors to axis handles
%   AX_POS         -   Show mouse position
%   CONE3D         -   Draw arrow 3D
%   CONTOURZ       -   3D contour plot on a surface
%   COPY_FIGURE    -   Copy objects of an axis to another
%   CYL            -   Draw cylinder
%   DIST_LABEL     -   Insert distance label
%   FILL_BOX       -   Fill rectangle
%   GEODIST        -   Display distances on axis
%   GEO_LABELS     -   Format tickLabels
%   ISPROP         -   Check handle property
%   M_AXIS         -   Set axis limits
%   M_CLABEL       -   Modified version of clabel
%   M_INPUT        -   Graphical input from mouse
%   MYHIST         -   Histogram, another version
%   MYHIST2        -   Histogram, another version, horizontal
%   MYSTEM         -   Modified version of stem
%   NORTH_ARROW    -   Draw direction arrow
%   PLOT_AXIS      -   Plot axes on current axis
%   PLOT_BOX       -   Plot rectangle
%   PLOT_ELLIPSE   -   Draw ellipse using major, minor, inc and phase
%   PLOT_TIDESTRUC -   Plot ellipses from LSF or T_TIDE output
%   SETA2D         -   Plot 2D filled arrow
%   SPH            -   Draw sphere taking in account DataAspectRatio
%   SPH2           -   Draw circle taking in account DataAspectRatio
%   UD_HANDLES     -   Change position of current axis children
%   VECTOR         -   Draw arrow 2D or 3D (w=0)
%   VECTOR2D       -   Draw arrow 2D
%   W_ROSE         -   Draw wind rose
%   WIND_ARROW     -   Plot wind direction
%   WIND_ROSE      -   Draw wind rose
%
% img/draw_bar: Drawing utilities
%   BLIN           -   Add broken line to current axis
%   CIRC           -   Add circumference to current axis
%   DRAW_BAR       -   Add drawing utilities to current figure
%   SPL            -   Add spline line to current axis
%   SQR            -   Add rectangle to current axis
%   TOGGLE_OBJS    -   Toggle DRAW_BAR objects
%
% roms: Data extraction and visualisation of ROMS NetCDF files
%   BAT_SMOOTH     -   Smooth ROMS NetCDF grid file
%   EDITMASK       -   Edit land mask of ROMS NetCDF grid file
%   FILL_BORDER    -   Fill around ROMS region
%   FLT_AGE        -   Get ROMS float age
%   GET_SIGMA      -   Get s-coordinates parameters from ROMS file (deprecated)
%   GET_STA        -   Get vertical profile of a ROMS variable
%   M_HSLOPE       -   Compute bathymetry slope
%   PLOT_BORDER    -   Plot ROMS rho border/extremes box
%   PLOT_BORDER2D  -   Display ROMS grid 2D
%   PLOT_BORDER3D  -   Display ROMS grid boundaries
%   ROMS_BORDER    -   Get ROMS region border
%   ROMS_DT        -   Get time info from ROMS output file
%   ROMS_EXTRACTSTR-   Get range of ROMS NetCDF variables
%   ROMS_GRID      -   Get ROMS grid data x, y, h and mask
%   RUSE           -   Extract ROMS NetCDF variables
%   S_LEVELS       -   Get vertical s-coordinates levels
%   S_PARAMS       -   Get s-coordinates parameters from ROMS file
%   SHOW_MASK      -   Display mask from ROMS grid or history file
%   STA_GRID_POS   -   Plot ROMS stations location
%   STA_TIME       -   Get interval and length of ROMS output stations
%   STA_YX         -   Get dimensions of longitude in ROMS stations file
%
% roms/roms_ncep: Creation of ROMS bulk fluxes forcing files from NCEP database
%   NCEP_GEN       -   Generate ROMS bulk fluxes forcing files from NCEP
%   NCEP_GENCDL    -   Create NetCDF cdl and nc file of ROMS bulk forcings
%   NCEP_GENFRC    -   Create NetCDF ROMS bulk forcing file
%   NCEP_GETFILE   -   Download NCEP reanalysis file
%   NCEP_GETVAR    -   Get NCEP bulk flux variable
%   NCEP_ISTART    -   Get start and end time indices in NCEP files
%   NCEP_SETTINGS  -   Information about NCEP bulk fluxes files
%   NCEP_UVCOMP    -   Compare NCEP winds of several years
%   NCEP_VAR2GRID  -   Interpolate NCEP variable to ROMS grid
%
% roms/roms_series: Extraction of time series and z-profiles from ROMS output NetCDF files
%   ROMS_TS        -   Extract time series and z-profiles from ROMS output
%   ROMS_TSF       -   Filter ROMS time series
%
% roms/roms_slice: Extraction of 2D slices from ROMS output NetCDF files
%   ROMS_SLICE     -   Utility to extract 2D slices from ROMS output
%   ROMS_SLICEI    -   Make ROMS slice across eta direction (i=const)
%   ROMS_SLICEJ    -   Make ROMS slice across xi direction (j=const)
%   ROMS_SLICEK    -   Make ROMS slice at s-level (k=const)
%   ROMS_SLICELAT  -   Make ROMS slice across meridional direction (lat=const)
%   ROMS_SLICELON  -   Make ROMS slice across zonal direction (lon=const)
%   ROMS_SLICEUVW  -   Get velocity field at ROMS slice
%   ROMS_SLICEUVW3 -   Get 3D velocity field at ROMS slice
%   ROMS_SLICEZ    -   Make ROMS slice at z=const
%
% tools: Mathematical and miscellaneous tools
%   ATAN3          -   Inverse tangent [0:360[
%   CC             -   Clear and close all
%   CORR_XY        -   Correlation coefficient between two series
%   DEG2RAD        -   Degree to radian conversion
%   DSP            -   Run UNIX display
%   EXPLODE        -   Divide  a string by a character
%   FILE_LIST      -   List files of a directory
%   FREQ2NAME      -   Convert tidal frequency to name
%   FSA            -   Fourier Spectral Analysis
%   GETF           -   Get filename
%   GV             -   Run UNIX gv
%   HV_DIST        -   Compute number of grid points according to resolution
%   INTEG          -   Riemann integration
%   INTER2PI       -   Angles interpolation
%   ISNUMBER       -   Check if numeric value
%   LON2XCOAST     -   Convert lon/lat to distance to coast
%   LSF            -   Harmonic analysis of time series using Least Squares Fit
%   M_SMOOTH       -   Smooth 2D array
%   MAF            -   Moving Average Filter
%   MAT_TEX        -   Create latex table with matlab matrice
%   MAX_MIN        -   Get extremes of series
%   MC_READ        -   Read multi column text file
%   NAME2FREQ      -   Convert tidal name to frequency
%   NAN2ZERO       -   Convert NaNs to zero
%   NAN_COUNT      -   Count NaNs
%   RAD2DEG        -   Radian to degree conversion
%   ROT2D          -   2D rotation
%   ROT3D          -   3D rotation
%   ROT_LONGITUDE  -   Swap longitude between -180:180 and 0:360
%   SIGN_SWAP      -   Get indices of sign change
%   SMOOT_R        -   Smooth 2D array with a square filter
%   SPH_DIST       -   Shortest distance between two points on a sphere
%   SUBNAME        -   Get part of string
%   T0_T_TIDE      -   Adjust T_TIDE output to beginning of series
%   TD_READ        -   Time data read
%   VAR_BORDER     -   Get border of 2D array
%   VI             -   Run UNIX vi
%   ZERO2NAN       -   Convert zeros to NaN
%
% toolsnc: Extraction of information from NetCDF files
%   N_FILEATT      -   Get global attributes of NetCDF file
%   N_FILEATTEXIST -   Check if NetCDF file attribute exists
%   N_FILEDIM      -   Get dimensions of NetCDF file
%   N_FILEDIMEXIST -   Check if NetCDF file dimension exists
%   N_VARARRAYDIM  -   Get array dimension of a NetCDF variable, range or size
%   N_VARATT       -   Get attributes of NetCDF variable
%   N_VARATTEXIST  -   Check if NetCDF variable attribute exists
%   N_VARDIM       -   Get dimensions of NetCDF variable
%   N_VARDIMEXIST  -   Check if NetCDF variable dimension exists
%   N_VAREXIST     -   Check if NetCDF variable exists
%   N_VARSCALE     -   Get scale and offset of NetCDF variable
%   N_VARSIZE      -   Get size of a NetCDF variable or range
%   SHOW           -   Display contents of NetCDF file
%   USE            -   Load NetCDF variable
%
%
%   MMA 4-5-2005, martinho@fis.ua.pt
