function edittmask(file,action)
%EDITMASK   Edit land mask of ROMS NetCDF grid file
%   EDITMASK(FILE)
%   EDITMASK(BATHY_COUNTOURS)
%
%   input:
%      FILE   ROMS NetCDF grid file [ <none> ]
%      BATHY_COUNTOURS    depth contour to be added
%
%   comments:
%      without input argument FILE, the used is asked to choose one;
%      if a file coastline.mat with variables lon and lat is present
%      in path, the coast line is plotted; the user can however select
%      a new one using the menu .coast.
%      - The final file will be the same as input so, better copy the
%      original if you wanna keep it
%
%   usage:
%      editmask
%      % then you will prompted to select grid file
%      % click on menu <mask> to select points with mouse (right button)
%      % use left button to stop selection and start zoom on
%
%   MMA 1-10-2004, martinho@fis.ua.pt
%   11-1-2005, new version not based on pcolor
%    8-4-2005, added BATHY_COUNTOURS option
%
%   See also M_FILES, M_PACK

global DATA

% ----------- add bathy contours:
bathy_contours = [];
if nargin ==1
  if isnumeric(file)
    bathy_contours = file;
  end
end
% -------------------------------

if nargin == 0 | isnumeric(file)
  file = netcdf('*.nc');
  file = name(file);
end
if isempty(file) & nargin == 1
  return
end
if nargin < 2
  action = 'init';
end


if isequal(action,'init')

  DATA.fig = figure;
  set(gcf,'menubar','none','NumberTitle','off','name','editmask')

  DATA.file    = file;
  DATA.changed = 0;
  DATA.saved   = 0;

  DATA.menu.mask = uimenu('label','<mask>',   'callback',  'editmask(''action'',''mask'');'       );
  DATA.menu.coas = uimenu('label','.coast.',  'callback',  'editmask(''action'',''coastline'');'  );
  DATA.menu.save = uimenu('label','<save>',   'callback',  'editmask(''action'',''save'');'       );
  DATA.menu.zoom = uimenu('label','[zoom]',   'callback',  'editmask(''action'',''zoom'');'       );
  DATA.menu.fill = uimenu('label','-fill-',   'callback',  'editmask(''action'',''fill'');'       );
  DATA.menu.uv   = uimenu('label','-u-v-',    'callback',  'editmask(''action'',''uv'');'         );
  DATA.menu.quit = uimenu('label','-quit-',   'callback',  'editmask(''action'',''quit'');'       );


  % laod variables:
  isxy = 0;
  % ------------------------------ rho
  if n_varexist(file,'lon_rho')
    lonr = use(file,'lon_rho');
    isxy = 0;
  elseif n_varexist(file,'x_rho')
    lonr = use(file,'x_rho');
    isxy = 1;
  end

  if ~isxy
    if ~n_varexist(file,'lat_rho');
      disp('## missing variables...');
      return
    end
    latr = use(file,'lat_rho');
  else
    if ~n_varexist(file,'y_rho');
      disp('## missing variables...');
      return
    end
    latr = use(file,'y_rho');
  end

  % ------------------------------ u, v
  isuv = 1;
  if ~isxy
    if  n_varexist(file,'lon_u') & n_varexist(file,'lat_u') & n_varexist(file,'lon_v') & n_varexist(file,'lat_v')
      lonu = use(file,'lon_u');
      latu = use(file,'lat_u');
      lonv = use(file,'lon_v');
      latv = use(file,'lat_v');
    else
      isuv = 0;
    end
  else
    if  n_varexist(file,'x_u') & n_varexist(file,'y_u') & n_varexist(file,'x_v') & n_varexist(file,'y_v')
      lonu = use(file,'x_u');
      latu = use(file,'y_u');
      lonv = use(file,'x_v');
      latv = use(file,'y_v');
    else
      isuv = 0;
    end
  end

  if ~isuv
    lonu = ( lonr(:,1:end-1) + lonr(:,2:end) )/2;
    latu = ( latr(:,1:end-1) + latr(:,2:end) )/2;

    lonv = ( lonr(1:end-1,:) + lonr(2:end,:) )/2;
    latv = ( latr(1:end-1,:) + latr(2:end,:) )/2;
  end


  % ------------------------------ masks
  if  n_varexist(file,'mask_rho')
    maskr = use(file,'mask_rho');
  else
    maskr = ones(size(lonr));
  end

  if  n_varexist(file,'mask_u') &   n_varexist(file,'mask_v')
    masku = use(file,'mask_u');
    maskv = use(file,'mask_v');
  else
    [masku,maskv,pmask]=uvp_masks(maskr);
  end

  % ------------------------------ bathy contour:
  if ~isempty(bathy_contours) &  n_varexist(file,'h')
    h = use(file,'h');
  end

  % --------------------------------------------------------------------

  [lon,lat] = gen_grid(lonr,latr);

  pc = pcolor(lon,lat,nan*lon); set(pc,'edgecolor',[0.4700    0.7950    0.4940]);

  m_axis(lon,lat,.2,.2);
  hold on

  % rho, u, v
  set_points(lonr,latr,maskr,'rho');
  set_points(lonu,latu,masku,'u');
  set_points(lonv,latv,maskv,'v');

  % bathy contours:
  if ~isempty(bathy_contours) &  n_varexist(file,'h')
    contour(lonr,latr,h,[bathy_contours]);
  end

  eval('load coastline, cl = 1;','cl = 0;');
  if cl
    pcl=plot(lon,lat,'r'); set(pcl,'tag','coastline');
  end

  lh = .8;
  lw = .5;
  set(gcf,'units','normalized');
  fp = get(gcf,'position');
  set(gcf,'position',[0.5-lw/2 0.5-lh/2 lw lh]);
  set(gca,'position',[0.0738    0.0535    0.8989    0.9092]);


  % zomm on:
  zm = DATA.menu.zoom;
  zoom on
  set(zm,'foregroundcolor',[1 0 0]);

  DATA.xr = lonr;
  DATA.yr = latr;
  DATA.mr = maskr;
  DATA.mr0 = maskr;

  DATA.xu = lonu;
  DATA.yu = latu;
  DATA.mu = masku;

  DATA.xv = lonv;
  DATA.yv = latv;
  DATA.mv = maskv;


% -------------------------------------------------------------------- mask
elseif isequal(action,'mask')

  xr = DATA.xr;
  yr = DATA.yr;
  mr = DATA.mr;

  xu = DATA.xu;
  yu = DATA.yu;
  mu = DATA.mu;

  xv = DATA.xv;
  yv = DATA.yv;
  mv = DATA.mv;


  % zomm off:
  zm = DATA.menu.zoom;
  zoom off
  set(zm,'foregroundcolor',[0 0 0]);

  xi=0;
  while ~isempty(xi)
    [xi,yi] = m_input(1,'pointer','crosshair');
    if ~isempty(xi)
      dist = (xr-xi).^2 + (yr-yi).^2;
      [i,j] = find(dist == min(min(dist)));

      if mr(i,j) == 0, mr(i,j) =1; else, mr(i,j) = 0; end
      [mu,mv,mp]=uvp_masks(mr);

      DATA.mr = mr;
      DATA.mu = mu;
      DATA.mv = mv;
      set_points(xr,yr,mr,'rho')
      set_points(xu,yu,mu,'u')
      set_points(xv,yv,mv,'v')
    end
  end

  editmask('action','zoom');

  % check if changed:
  if ~isequal(mr,DATA.mr0)
    DATA.changed = 1;
  else
    DATA.changed = 0;
  end


elseif isequal(action,'zoom')
  zm = DATA.menu.zoom;
  color = get(zm,'foregroundcolor');
  if color==[0 0 0]
    zoom on
    set(zm,'foregroundcolor',[1 0 0]);
  else
    zoom off
    set(zm,'foregroundcolor',[0 0 0]);
  end

% -------------------------------------------------------------------- quit
elseif isequal(action,'quit')
  changed = DATA.changed;
  saved   = DATA.saved;
  file    = DATA.file;
  fig     = DATA.fig;

 if changed
    s = {'mask was changed', 'wanna quit without save it first ?' };
    answer = questdlg(s,'EditMask', 'yes','no','no');
  elseif ~saved
    s = {'no changes done in grid: ',file};
    msgbox(s,'EditMask','help','modal');
    answer = 'yes';
  else % saved
    s = {'mask successfully changed on file: ',file};
    msgbox(s,'EditMask','help','modal');
    answer = 'yes';
  end
  if isequal(answer,'yes'), close(fig); end

% -------------------------------------------------------------------- save
elseif isequal(action,'save')
  changed = DATA.changed;
  if ~changed
    msgbox('nothing to save','EditMask','help','modal');
    return
  end

  file = DATA.file;
  nc = netcdf(file,'write');
    rmask = DATA.mr;
    [umask,vmask,pmask]=uvp_masks(rmask);

    nc{'mask_rho'}(:) = rmask;
    nc{'mask_u'}(:)   = umask;
    nc{'mask_v'}(:)   = vmask;
    nc{'mask_psi'}(:) = pmask;

    msgbox(['file ',file,' saved'],'EditMask','help','modal');
  nc = close(nc);

  DATA.changed = 0;
  DATA.saved   = 1;
  DATA.mr0     = DATA.mr;

  zm = DATA.menu.zoom;
  set(zm,'foregroundcolor',[0 0 0]);
  editmask('action','zoom');

% -------------------------------------------------------------------- fill
elseif isequal(action,'fill')

  obj = findobj(gca,'tag','land');
  if ~isempty(obj) & ishandle(obj)
    delete(obj);
  else
    set(gcf,'pointer','watch')
    xr = DATA.xr;
    yr = DATA.yr;
    mr = DATA.mr;
    [lon,lat] = gen_grid(xr,yr);
    EraseMode = 'normal';
    for i=1: size(mr,1)
      for j=1:size(mr,2)
        x = [lon(i,j) lon(i,j+1) lon(i+1,j+1) lon(i+1,j)];
        y = [lat(i,j) lat(i,j+1) lat(i+1,j+1) lat(i+1,j)];
        if mr(i,j) == 0
          fl = fill(x,y,'y'); set(fl,'edgecolor','none','erasemode',EraseMode,'facealpha',0.5,'tag','land');
        end
      end
    end
    set(gcf,'pointer','arrow')

  end

  zm = DATA.menu.zoom;
  set(zm,'foregroundcolor',[0 0 0]);
  editmask('action','zoom');

% -------------------------------------------------------------------- uv
elseif isequal(action,'uv')
  u=findobj(gca,'tag','u');
  v=findobj(gca,'tag','v');
  vis = get(u,'visible');

  if isequal(vis,'on')
    set(u,'visible','off');
    set(v,'visible','off');
  else
    set(u,'visible','on');
    set(v,'visible','on');
  end

  zm = DATA.menu.zoom;
  set(zm,'foregroundcolor',[0 0 0]);
  editmask('action','zoom');

% -------------------------------------------------------------------- coastline
elseif isequal(action,'coastline')
  cl = getf;
  if isempty(cl), return, end
  ll=load(cl);

  % check if coast is plotted:
  obj = findobj(gca,'tag','coastline');
  if isempty(obj)
    pcl=plot(ll.lon,ll.lat,'r');
    set(pcl,'tag','coastline');
  else
    set(obj,'xdata',ll.lon,'ydata',ll.lat);
  end

  zm = DATA.menu.zoom;
  set(zm,'foregroundcolor',[0 0 0]);
  editmask('action','zoom');

end


function set_points(x,y,m,type)
global DATA
switch type
  case 'rho'
    opt = 'ko';
  case 'u'
    opt = 'b>';
  case 'v'
    opt = 'r^';
end

i  = m~=0;
obj = findobj(gca,'tag',type);
if isempty(obj)
  pl =plot(x(i),y(i),opt); set(pl,'Markersize',4,'tag',type);
else
  set(obj,'xdata',x(i),'ydata',y(i));
end


function [lon,lat] = gen_grid(lonr,latr)

lon = (lonr(:,2:end)+lonr(:,1:end-1))/2;
lat = (latr(:,2:end)+latr(:,1:end-1))/2;

lon = (lon(2:end,:)+lon(1:end-1,:))/2;
lat = (lat(2:end,:)+lat(1:end-1,:))/2;


lon(2:end+1,2:end+1) = lon;
lon(1,:) = lon(2,:) - (lon(3,:) - lon(2,:));
lon(end+1,:) = lon(end,:) + (lon(end,:) - lon(end-1,:));

lon(:,1) = lon(:,2) - (lon(:,3) - lon(:,2));
lon(:,end+1) = lon(:,end) + (lon(:,end) - lon(:,end-1));


lat(2:end+1,2:end+1) = lat;
lat(1,:) = lat(2,:) - (lat(3,:) - lat(2,:));
lat(end+1,:) = lat(end,:) + (lat(end,:) - lat(end-1,:));

lat(:,1) = lat(:,2) - (lat(:,3) - lat(:,2));
lat(:,end+1) = lat(:,end) + (lat(:,end) - lat(:,end-1));
