function [x,y,z,xc,yc,zc] = roms_border(file)
%ROMS_BORDER   Get ROMS region border
%   [X,Y,Z,XC,YC,ZC] = ROMS_BORDER(FNAME)
%
%   input:
%      FNAME   ROMS grid or history file [ {<none>} <filename> ]
%              need variables: lon_rho or x_rho; lat_rho  or y_rho and h
%
%   output:
%      X   border x
%      Y   border y
%      Z   border bottom (negative depth)
%      XC, YC, ZC   values at the 4 corners
%
%   example:
%      fname = 'grid.nc'
%      [x,y,h,xc,yc,hc] = roms_border(fname);
%      figure
%      plot(x,y); hold on
%      plot3(x,y,h);
%      plot3([xc(1) xc(1) nan xc(2) xc(2) nan xc(3) xc(3) nan xc(4) xc(4)],...
%            [yc(1) yc(1) nan yc(2) yc(2) nan yc(3) yc(3) nan yc(4) yc(4)],...
%            [hc(1) 0     nan hc(2) 0     nan hc(3) 0     nan hc(4) 0    ],'r')
%     view(3)
%
%   MMA 18-8-2004, martinho@fis.ua.pt
%
%   See Also PLOT_BORDER3D

x=[]; xc=[];
y=[]; yc=[];
z=[]; zc=[];

if nargin == 0
  file = getf;
end

if isempty(file);
  return
end

% set X, Y and  H
if     n_varexist(file,'lon_rho'), X = 'lon_rho';
elseif n_varexist(file,'x_rho'),   X = 'x_rho';
else   fprintf(1,'» lon_rho or x_rho do not exist\n'); return
end

if     n_varexist(file,'lat_rho'), Y = 'lat_rho';
elseif n_varexist(file,'y_rho'),   Y = 'y_rho';
else   fprintf(1,'» lat_rho or y_rho do not exist\n'); return
end

H = 'h';

% get data:
nc=netcdf(file);

xl = nc{X}(:,1);
yl = nc{Y}(:,1);
zl = nc{H}(:,1);

xt = nc{X}(end,:);  xt = xt';
yt = nc{Y}(end,:);  yt = yt';
zt = nc{H}(end,:);  zt = zt';

xr = nc{X}(:,end);  xr = flipud(xr);
yr = nc{Y}(:,end);  yr = flipud(yr);
zr = nc{H}(:,end);  zr = flipud(zr);

xb = nc{X}(1,:);    xb = flipud(xb');
yb = nc{Y}(1,:);    yb = flipud(yb');
zb = nc{H}(1,:);    zb = flipud(zb');

nc=close(nc);

x =  [xl; xt; xr; xb];
y =  [yl; yt; yr; yb];
z = -[zl; zt; zr; zb];

% corners:
xc =  [xl(1) xl(end) xr(1) xr(end)];
yc =  [yl(1) yl(end) yr(1) yr(end)];
zc = -[zl(1) zl(end) zr(1) zr(end)];
