function [x,y,h,m,labels] = roms_grid(file,varargin)
%ROMS_GRID   Get ROMS grid data x, y, h and mask
%   [X,Y,H,M,LABELS] = ROMS_GRID(FILE,VARARGIN)
%
%   input:
%      FILE   ROMS grid or history file [ {<none>} <filename> ]
%      VARARGIN:
%         'slicei',i   returns variables at slice I=i
%         'slicej',j   returns variables at slice J=j
%         'slicelon',lon[npts]  returns variables at slice longitude=lon
%         'slicelat',lat[npts]  returns variables at slice latitude=lat
%                               npts is the number of points to use in
%                               interpolation [ 100 ]
%
%   output:
%      X   grid x (lon_rho or x_rho)
%      Y   grid y (lat_rho or y_rho)
%      H   grid depth (h)
%      M   grid mask (mask_rho)
%      LABELS   X and Y names
%
%   example:
%      file = 'grid.nc';
%      [x,y,h,m,labels] = roms_grid(file);
%      surf(x,y,-h,'facecolor','none','edgecolor','g')
%      xlabel(labels.x); ylabel(labels.y,'interpreter','none')
%      hold on
%      [x,y,h,m,labels] = roms_grid(file,'slicej',20);
%      plot3(x,y,-h,'r','linewidth',3);
%      [x,y,h,m,labels] = roms_grid(file,'slicelat',[40 20]);
%      plot3(x,y,-h,'k','linewidth',3);
%
%   MMA 18-8-2004, martinho@fis.ua.pt
%
%   See Also PLOT_BORDER3D, ROMS_BORDER

x=[];
y=[];
h=[];
m=[];
labels=[];

if nargin == 0
  file = getf;
end

if isempty(file);
  return
end


doslicei   = 0;
doslicej   = 0;
doslicelon = 0;
doslicelat = 0;
nLON = 100; % n. of points to use in interpolation at lon slice
nLAT = 100; % n. of points to use in interpolation at lat slice
griddataMethod = 'cubic';

vin = varargin;
for i=1:length(vin)
  if isequal(vin{i},'slicei')
    doslicei = 1;
    I = vin{i+1};
  end
  if isequal(vin{i},'slicej')
    doslicej = 1;
    J = vin{i+1};
  end
  if isequal(vin{i},'slicelon')
    doslicelon = 1;
    LON = vin{i+1};
    if length(LON) > 1
      nLON = LON(2);
      LON  = LON(1);
    end
  end
  if isequal(vin{i},'slicelat')
    doslicelat = 1;
    LAT = vin{i+1};
    if length(LAT) > 1
      nLAT = LAT(2);
      LAT  = LAT(1);
    end
  end
end


if any([doslicei doslicej doslicelon doslicelat])
  dosliceNone = 0;
else
  dosliceNone = 1;
end

% set X, Y, H and MASK(M):
if     n_varexist(file,'lon_rho'), X = 'lon_rho';
elseif n_varexist(file,'x_rho'),   X = 'x_rho';
else   fprintf(1,'» lon_rho or x_rho do not exist\n'); return
end

if     n_varexist(file,'lat_rho'), Y = 'lat_rho';
elseif n_varexist(file,'y_rho'),   Y = 'y_rho';
else   fprintf(1,'» lat_rho or y_rho do not exist\n'); return
end

H = 'h';

M = 'mask_rho';

% get data:
nc=netcdf(file);

if dosliceNone | doslicelon | doslicelat
  x = nc{X}(:);
  y = nc{Y}(:);
  h = nc{H}(:);
  m = nc{M}(:);
end

if doslicei    % --------------------- slice I
  idx  = 2;
  vidx = I;
  if vidx <= 0
    fprintf(1,'» bad J ( <= 0 )\n');
    close(nc);
    return
  end
  if ~(size(nc{X},idx) >= vidx & size(nc{Y},idx) >= vidx &  size(nc{H},idx) >= vidx & size(nc{M},idx) >= vidx & vidx > 0 )
    fprintf(1,'» I exceeds variables dimensions\n');
    close(nc);
    return
  end
  x = nc{X}(:,I);
  y = nc{Y}(:,I);
  h = nc{H}(:,I);
  m = nc{M}(:,I);

elseif doslicej % --------------------- slice J
  idx = 1;
  vidx = J;
  if vidx <= 0
    fprintf(1,'» bad J ( <= 0 )\n');
    close(nc);
    return
  end
  if ~(size(nc{X},idx) >= vidx & size(nc{Y},idx) >= vidx &  size(nc{H},idx) >= vidx & size(nc{M},idx) >= vidx & vidx > 0)
    fprintf(1,'» J exceeds variables dimensions\n');
    close(nc);
    return
  end
  x = nc{X}(J,:);
  y = nc{Y}(J,:);
  h = nc{H}(J,:);
  m = nc{M}(J,:);

elseif doslicelon % --------------------- slice lon
  XI = LON;
  YI = linspace(min(min(y)),max(max(y)),nLON);
  h = griddata(x,y,h,XI,YI,griddataMethod);
  m = griddata(x,y,m,XI,YI,griddataMethod);

  x = repmat(XI,size(YI));
  y = YI;

  % set nan what is outside region:
  [XB,YB]= roms_border(file); % region border
  i=inpolygon(x,y,XB,YB);
  h(i==0)=nan;
  m(i==0)=nan;

elseif doslicelat % --------------------- slice lat
  XI = linspace(min(min(x)),max(max(x)),nLAT);
  YI = LAT;
  h = griddata(x,y,h,XI,YI,griddataMethod);
  m = griddata(x,y,m,XI,YI,griddataMethod);

  x = XI;
  y = repmat(YI,size(XI));

  % set nan what is outside region:
  [XB,YB]= roms_border(file); % region border
  i=inpolygon(x,y,XB,YB);
  h(i==0)=nan;
  m(i==0)=nan;

end

nc=close(nc);

% labels (name of x and y):
labels.x=X;
labels.y=Y;
