function show_mask(file,varargin)
%SHOW_MASK   Display mask from ROMS grid or history file
%   SHOW_MASK(GRD,VARARGIN)
%   mask at rho is shown as o
%   mask at u               >
%   mask at v               ^
%
%   input:
%      GRD   name of the NetCDF file [ {<none>} <filename> ]
%            should be grid or history file
%      VARARGIN:
%         'fill', {1} 0, will created filled boxes aat each cell
%                        for better visualisation. It may be heavy
%                        with large grids
%
%   example:
%      show_mask('grid.nc')
%      show_mask('his.nc','fill',0)
%
%   MMA 5-5-2004, martinho@fis.ua.pt
%   11-1-2005, new version not based on pcolor
%
%   See also M_FILES, M_PACK

if nargin == 0
  file = netcdf('*.nc');
  file=name(file);
end
if isempty(file) & nargin == 1
  return
end

dofill = 1;
vin = varargin;
for i=1:length(vin)
  if isequal(vin{i},'fill')
    dofill = vin{i+1};
  end
end

if n_varexist(file,'lon_rho')
  lonr = use(file,'lon_rho');
elseif n_varexist(file,'x_rho')
  lonr = use(file,'x_rho');
end

if n_varexist(file,'lat_rho')
  latr = use(file,'lat_rho');
elseif n_varexist(file,'y_rho')
  latr = use(file,'y_rho');
end

if  n_varexist(file,'mask_rho')
  maskr = use(file,'mask_rho');
else
  maskr = ones(size(lonr));
end

if  n_varexist(file,'mask_u') &   n_varexist(file,'mask_v')
  masku = use(file,'mask_u');
  maskv = use(file,'mask_v');
else
  [masku,maskv,pmask]=uvp_masks(maskr);
end

% --------------------------------------------------------------------
[m,n] = size(lonr);
[lonr,latr] = meshgrid(1:n,1:m);
lonu = (lonr(:,1:end-1) + lonr(:,2:end) )/2;
latu = (latr(:,1:end-1) + latr(:,2:end) )/2;
lonv = (lonr(1:end-1,:) + lonr(2:end,:) )/2;
latv = (latr(1:end-1,:) + latr(2:end,:) )/2;

[lon,lat] = gen_grid(lonr,latr);

% --------------------------------------------------------------------

pc = pcolor(lon,lat,nan*lon); set(pc,'edgecolor',[0.4700    0.7950    0.4940]);
m_axis(lon,lat,.2,.2);
hold on

% rho, u, v
set_points(lonr,latr,maskr,'rho');
set_points(lonu,latu,masku,'u');
set_points(lonv,latv,maskv,'v');

lh = .8;
lw = .5;
set(gcf,'units','normalized');
fp = get(gcf,'position');
set(gcf,'position',[0.5-lw/2 0.5-lh/2 lw lh]);
set(gca,'position',[0.0738    0.0535    0.8989    0.9092]);

if dofill
  EraseMode = 'normal';
  for i=1: size(maskr,1)
    for j=1:size(maskr,2)
      x = [lon(i,j) lon(i,j+1) lon(i+1,j+1) lon(i+1,j)];
      y = [lat(i,j) lat(i,j+1) lat(i+1,j+1) lat(i+1,j)];
      if maskr(i,j) == 0
        fl = fill(x,y,'y'); set(fl,'edgecolor','none','erasemode',EraseMode,'facealpha',0.5,'tag','land');
      end
    end
  end

end


function set_points(x,y,m,type)
global DATA
switch type
  case 'rho'
    opt = 'ko';
  case 'u'
    opt = 'b>';
  case 'v'
    opt = 'r^';
end

i  = m~=0;
obj = findobj(gca,'tag',type);
if isempty(obj)
  pl =plot(x(i),y(i),opt); set(pl,'Markersize',4,'tag',type);
else
  set(obj,'xdata',x(i),'ydata',y(i));
end


function [lon,lat] = gen_grid(lonr,latr)

lon = (lonr(:,2:end)+lonr(:,1:end-1))/2;
lat = (latr(:,2:end)+latr(:,1:end-1))/2;

lon = (lon(2:end,:)+lon(1:end-1,:))/2;
lat = (lat(2:end,:)+lat(1:end-1,:))/2;


lon(2:end+1,2:end+1) = lon;
lon(1,:) = lon(2,:) - (lon(3,:) - lon(2,:));
lon(end+1,:) = lon(end,:) + (lon(end,:) - lon(end-1,:));

lon(:,1) = lon(:,2) - (lon(:,3) - lon(:,2));
lon(:,end+1) = lon(:,end) + (lon(:,end) - lon(:,end-1));


lat(2:end+1,2:end+1) = lat;
lat(1,:) = lat(2,:) - (lat(3,:) - lat(2,:));
lat(end+1,:) = lat(end,:) + (lat(end,:) - lat(end-1,:));

lat(:,1) = lat(:,2) - (lat(:,3) - lat(:,2));
lat(:,end+1) = lat(:,end) + (lat(:,end) - lat(:,end-1));
