function s = fsa(x,interval,output,fopen_opt)
%FSA   Fourier Spectral Analysis
%   S = FSA(X,INTERVAL,OUTPUT,OPT)
%
%   input:
%      X   series
%      INTERVAL   data sampling interval (hour)
%      OUTPUT     place(fid or filename)/show results [ {1} 0 <filename> ]
%      OPT        fopen permissions [ 'w' ]
%
%   output:
%      S   structure of results, .f .T .amp .pha (frequency, period, 
%          amplitude and phase)
%
%   comment:
%      if function max_min is not in path, all results will appear in 
%      output, otherwise, only the ten major will
%
%   example:
%      interval=.1;
%      t=0:interval:24*100;
%      y=cos(2*pi*t/12-30*pi/180)+2*cos(2*pi*t/24-80*pi/180);
%      s=fsa(y,interval);
%      % s=fsa(y,interval,'file.dat');
%      figure
%      plot(s.T,s.amp), xlim([0 30]); grid
%
%   MMA 8-12-2002, martinho@fis.ua.pt
%   Revision 10-2003
%
%   See also MAX_MIN, LSF

if nargin < 4
  fopen_opt='w';
end
if nargin < 3 
  output=1;
end
if nargin < 2
  error('## x and interval are needed...')
end

%=====================================================================
% FFT, do not edit:
%=====================================================================
N=length(x);Ni=N;
N=N-mod(N,2);
n=N/2;
x=x(1:N);
y=fft(x);
a0 = y(1)/N;
a = 2*real(y)/N;
b = -2*imag(y)/N;
amp=sqrt(a.^2+b.^2);
pha=atan3(b,a);
f=(0:N-1)/(N*interval);
%=====================================================================
% data:
f=f(2:n+1);       %  FREQUENCY
T=1./f;           %  PERIOD
amp=amp(2:n+1)';  %  AMPLITUDE
pha=pha(2:n+1)';  %  PHASE
%=====================================================================
% FFT done.
%=====================================================================

s.f=reshape(f,length(f),1);
s.T=reshape(T,length(T),1);
s.amp=reshape(amp,length(amp),1);
s.pha=reshape(pha,length(pha),1);
s.N=Ni;
s.n=n;
s.a0=a0;

if output ~=0
%=====================================================================
% DISPLAY:
%=====================================================================
% choose main components:

if exist('max_min') == 2 % m file
  [Max, Min]=max_min(s.amp,0);
  [I,J]=sort(Max.val);
  Mamp=Max.val(J);
  MT=s.T(Max.i(J));
  Mpha=s.pha(Max.i(J));
  disp_max=10;
  warn=0;
else
  Mamp=s.amp;
  MT=s.T;
  Mpha=s.pha;
  Max.i=1:s.n;
  disp_max=s.n;
  warn=1;
end

if isstr(output)
  fid=fopen(output,fopen_opt);
else
  fid=1;
end

fprintf(fid,'\n');
fprintf(fid,'*******************************************\n');
fprintf(fid,'   Fourier Spectral Analysis\n');
fprintf(fid,' Date: %s\n',datestr(now));
fprintf(fid,' Serie Length: %d\n',N);
fprintf(fid,' Interval: %2.2f h\n',interval);
fprintf(fid,' Days: %2.2f\n',(N-1)*interval/24);
fprintf(fid,' a0: %4.4f\n',s.a0);
if ~warn
  fprintf(fid,' Main signs\n');
end
fprintf(fid,'-------------------------------------------\n');
fprintf(fid,'    Period     Amp      Pha\n');

for j=1:min(length(Max.i),disp_max)
   fprintf(fid,'%10.4f  %8.4f %10.4f\n', MT(end-j+1), Mamp(end-j+1), Mpha(end-j+1) );
end

fprintf(fid,'*******************************************\n');
if isstr(output)
  fclose(fid);
end

if warn
  warning('## max_min.m not in path...');
end

end % output ~= 0
