function [tidestruc,xout] = lsf(t,f,tide,output,fopen_opt)
%LSF   Harmonic analysis of time series using Least Squares Fit
%[TIDESTRUC,XOUT] = LSF(T,F,TIDE,OUTPUT,OPT)
%    Returns amplitude (C) and phase (pha) of f(t) of frequencies in tide
%    ie, serie is returned as a sum of C(i)*cos(2*pi*t/T(i)-pha(i))
%
%   input:
%      T        time in the series (hours), or interval
%      F        series
%      TIDE     array of constituents, like [12.42,12.00,12.66], or
%               ['M2','S2','N2'] if T_TIDE constituents are in path as
%               well as NAME2FREQ
%      OUTPUT   place (fid or filename)/show results [ {1} 0 <filename> ]
%      OPT      fopen permissions [ 'w' ]
%
%   output:
%      TIDESTRUC   structure to be used by T_TIDE (t_predic) with extra
%                  elements .C and .pha (amplitudes and phases)
%      XOUT        C(i)*cos(2*pi*t/T(i)-pha(i))
%
%   comment:
%      the file constituents.mat of the T_TIDE package must be in path
%      if tidal names are to be used as TIDE
%      TIDESTRUC is ready to be used by T_TIDE, but without proper error
%      estimates (confidence intervals) as in T_TIDE
%      if f is imag, ellipse parameters are returned, semimajor axis
%      semininor axis, inclination and phase in the columns 1, 3, 5 and 7
%      of matrice TIDESTRUC.tidecon (just like in T_TIDE)
%      T_TIDE is a Rich Pawlowicz's Matlab toolbox available at
%      http://www2.ocgy.ubc.ca/~rich/
%
%   example:
%      % f is real
%      t=0:24*10;
%      y=cos(2*pi*t/12-30*pi/180)+2*cos(2*pi*t/12.42060-80*pi/180);
%      [tidestruc,xout]=lsf(t,y,['M2';'S2']);
%      figure
%      plot(t,y); hold on
%      plot(t,xout,'r--')
%      % f is imag
%      t=0:24*30;
%      u=cos(2*pi*t/12-30*pi/180);
%      v=cos(2*pi*t/12);
%      f=u+sqrt(-1)*v;
%      [tidestruc,xout]=lsf(t,f,['M2';'S2']);
%      figure
%      subplot(2,1,1)
%      plot(t,real(f),t,real(xout),'r--'); title('u')
%      subplot(2,1,2)
%      plot(t,imag(f),t,imag(xout),'r--'); title('v')
%
%   MMA 31-7-2002, martinho@fis.ua.pt
%          1-2003
%       18-7-2003 (add ellipse)
%   Revision 10-2003
%
%   See also FSA, NAME2FREQ

if nargin < 5
  fopen_opt='w';
end
if nargin < 4
  output=1;
end
if nargin < 3
  error('## t, f and tide are needed ...');
end

if ~ isstr(tide)
   T=tide;
else
  if ~isequal(exist('name2freq'),2)
    error('name2freq not detected, use periods instead of names')
    return
  end
  for i=1:size(tide,1)
    T(i)=1/name2freq(tide(i,:),0);
  end
end
w=1./T;
w=reshape(w,length(w),1);

if size(t)==1
  % consider t the interval
  t=t*[0:length(f)-1];
end

t=reshape(t,1,length(t));
f=reshape(f,1,length(f));
if ~isequal(length(t),length(f))
  error('t and f must be vectors  and have the same length');
  return
end

D1=0;
D2=0; % 2D!
if isreal(f)
  D1=1;
else
  D2=1;
end

%---------------------------------------------------------------------
%calculus:
%---------------------------------------------------------------------
if D1
% Least Squares Fit:
  [C,pha]=do_lsf(t,f,w);
% xout:
  xout=do_xout(t,C,pha,T);
% correlation:
  corr=corr_xy(f,xout);
% tidestruc:
  tidestruc=gen_tidestruc(tide,w,C,pha,corr);
elseif D2
% Least Squares Fit:
  fu=real(f);
  [Cu,phau]=do_lsf(t,fu,w);
  fv=imag(f);
  [Cv,phav]=do_lsf(t,fv,w);
  C=Cu+sqrt(-1)*Cv;
  pha=phau+sqrt(-1)*phav;
% xout:
  xoutu=do_xout(t,Cu,phau,T);
  xoutv=do_xout(t,Cv,phav,T);
  xout=xoutu+sqrt(-1)*xoutv;
% correlation:
  corru=corr_xy(fu,xoutu);
  corrv=corr_xy(fv,xoutv);
  corr=corru+sqrt(-1)*corrv;
% tidestruc:
  tidestruc=gen_tidestruc(tide,w,C,pha,corr);
end

%---------------------------------------------------------------------
% display:
%---------------------------------------------------------------------
if ~isequal(output,0);
N=length(f);
interval=t(2)-t(1);
if isstr(output)
  fid=fopen(output,fopen_opt);
else
  fid=1;
end
fprintf(fid,'\n');
fprintf(fid,'=====================================================\n');
fprintf(fid,'  Least Squares Fit Harmonic Analysis\n');
fprintf(fid,' Date: %s\n',datestr(now));
fprintf(fid,' Serie Length: %d\n',N);
fprintf(fid,' Interval: %2.2f h\n',interval);
fprintf(fid,' Days: %2.2f\n',(N-1)*interval/24);
fprintf(fid,'-------------------------------------------\n');
if D1
  fprintf(fid,'       Period    Amp      Pha\n');
  for j=1:length(T)
    if isempty(tidestruc.name)
      name='    ';
    else
      name=tidestruc.name(j,:);
    end
    fprintf(fid,'%0.4s %8.4f %8.4f %9.4f\n',name, T(j), C(j), pha(j));
  end
elseif D2
  [major,  ecc, inc, phase, w]=ap2ep(real(C), real(pha), imag(C), imag(pha));
  minor=major.*ecc;
  fprintf(fid,'       Period   major    minor    inc        pha\n');
  for j=1:length(T)
    if isempty(tidestruc.name)
      name='    ';
    else
      name=tidestruc.name(j,:);
    end
    fprintf(fid,'%0.4s %8.4f  %7.4f %8.4f %9.4f  %9.4f\n',name, T(j), major(j), minor(j), inc(j), phase(j));
  end
end
fprintf(fid,'\n');
fprintf(fid,' correlation: %s\n',num2str(corr));
fprintf(fid,'=====================================================\n');

end % go_display


%---------------------------------------------------------------------
% functions:
%---------------------------------------------------------------------

function [C,pha]=do_lsf(t,x,w)
  lx=length(x);
  lw=length(w);
  % init arrays:
  G=repmat(nan,2*lw,lx);
  a=repmat(nan,2*lw,2*lw);
  b=repmat(nan,1,2*lw);
  C=repmat(nan,1,lw);
  pha=repmat(nan,1,lw);
  for i=1:lw
    G(i*2-1,:)=cos(2*pi*w(i)*t);
    G(i*2,:)=sin(2*pi*w(i)*t);
  end
  for i=1:2*lw
   for j=1:2*lw
     a(i,j)=sum(G(j,:).*G(i,:));
   end
   b(i)=sum(x.*G(i,:));
  end
  X=b/a;
  for i=1:lw
    C(i)=sqrt(X(2*i-1)^2+X(2*i)^2);
    B=X(2*i);
    A=X(2*i-1);
    pha(i)=atan3(B,A);
  end


function teta=atan3(y,x)
  teta=atan2(y,x)*180/pi;
  if teta < 0
    teta=teta+360;
  end


function xout=do_xout(t,C,pha,T);
  xout=zeros(size(t));
  for i=1:length(T)
   xout=xout+C(i)*cos(2*pi*t/T(i)-pha(i)*pi/180);
  end


function r=corr_xy(x,y)
  x=double(x);
  y=double(y);
  x=x-mean(x);
  y=y-mean(y);
  r=sum(sum(x.*y))/sqrt(sum(sum(x.*x))*sum(sum(y.*y)));


function tidestruc=gen_tidestruc(tide,w,C,pha,corr)
  if isstr(tide)
    tidestruc.name=tide;
  else
    tidestruc.name='';
  end
  tidestruc.freq=w;
  tidestruc.corr=corr;
  if isreal(C)
    tidecon=[ C;  C;  pha;  zeros(size(pha)) ]';
    tidestruc.tidecon=tidecon;
    tidestruc.C=C;
    tidestruc.pha=pha;
  else
    Au=real(C);
    Av=imag(C);
    PHIu=real(pha);
    PHIv=imag(pha);
    [SEMA,  ECC, INC, PHA, w]=ap2ep(Au, PHIu, Av, PHIv);
    fmin=SEMA.*ECC;
    z=zeros(size(fmin));
    tidestruc.tidecon=[SEMA; SEMA; fmin; z; INC; z; PHA; z]';
  end
