function show(fname,opts,leng_str,output)
%SHOW   Display contents of NetCDF file
%   SHOW(FILE,OPTS,LENG_STR,OUTPUT)
%
%   input:
%      FILE       NetCDF file [ {<none>} <filename> ]
%      OPTS       show variables long_name and units and
%                 file  dimensions and attributes [ <0 0 0 0> ]
%      LENG_STR   maximum length of variable name and long_name
%                 string [ 25 ]
%      OUTPUT     write (fid or filename)/show results [ {1} <fid> <filename> ]
%
%   comment:
%      works with the NetCDF toolbox available at
%      http://crusty.er.usgs.gov/~cdenham/MexCDF/nc4ml5.html
%      if scale or offset are present for a var, then an '*' is written
%      before it, first '*' is for scale and second is for offset
%      File dimensions and attributes are currently printed in screen,
%      not in <filename>
%
%   example:
%     show
%     show('file.nc')
%     show('file.nc',[1 1 0])
%     show('file.nc',[0 1],30,'file.txt') 
%
%   MMA 2001, martinho@fis.ua.pt
%   Revision 12-2003
%   26-1-2005, small correction to be used also by r14
%    7 2-2005, add opt(3:4)
%
%   See also USE

openf=0;
if nargin < 4
  fid=1;
else
  if isstr(output)
    fid=fopen(output,'w');
    openf=1;
  else
    fid=output;
  end
end

if nargin < 3
  smax=25;
else
  smax=leng_str;
end

if nargin < 2
  show_lname = 0;
  show_units = 0;
  show_att   = 0;
  show_dim   = 0;
else
  show_lname=opts(1);
  eval('show_units = opts(2);','show_units = 0;');
  eval('show_att   = opts(3);','show_att   = 0;');
  eval('show_dim   = opts(4);','show_dim   = 0;');
end

if nargin == 0
  nc=netcdf('nowrite');
else
  nc=netcdf(fname,'nowrite');
end

if isempty(nc)
  return
end

fname=name(nc);
vv=var(nc);
nvars=length(vv);

% ---------------------------------------------------------- lengths :
l_Name      = [0 0];
l_Long_name = [0 0];
l_Size      = [0 0];
l_Units     = [0 0];
for i=1:nvars
  Name=name(vv{i});
  Long_name=nc{name(vv{i})}.long_name(:);
  Size=size(vv{i}); Size=num2str(Size);
  Units=nc{name(vv{i})}.units(:);

  l_Name(1)      = length(Name);
  l_Long_name(1) = length(Long_name);
  l_Size(1)      = length(num2str(Size));
  l_Units(1)     = length(Units);

  if l_Name(1) < l_Name(2)
    l_Name(1) = l_Name(2);
  end

  if l_Long_name(1) < l_Long_name(2)
    l_Long_name(1) = l_Long_name(2);
  end

  if l_Size(1) < l_Size(2)
    l_Size(1) = l_Size(2);
  end

  if l_Units(1) < l_Units(2)
    l_Units(1)=l_Units(2);
  end

   l_Name(2)      = l_Name(1);
   l_Long_name(2) = l_Long_name(1);
   l_Size(2)      = l_Size(1);
   l_Units(2)     = l_Units(1);
end

add=2;
LN  = min(smax,l_Name(1)      + add);
LLN = min(smax,l_Long_name(1) + add);
LS  = min(smax,l_Size(1)      + add);
LU  = min(smax,l_Units(1)     + add);

% ====================================================================
fprintf(1,'\n');

if show_att
  n_fileatt(fname);
  fprintf(1,'\n');
end

if show_dim
  n_filedim(fname);
  fprintf(1,'\n');
end

fprintf(fid,'## Data in NetCDF file \n');
fprintf(fid,'%s\n',fname);
fprintf(fid,'%s\n','');

for i=1:nvars

% --------------------------------------- search for scale and offset:
  is_scale=0;  str1='-';
  is_offset=0; str2='-';
  a=att(vv{i});
  for n=1:length(a)
    b=a{n};
    att_name=name(b);
    if isequal(att_name,'scale_factor');
      is_scale=1;
      str1='*';
    end
    if isequal(att_name,'add_offset');
      is_offset=1;
      str2='*';
    end
  end
% --------------------------------------------------------------------

  Name=name(vv{i});
  Long_name=nc{name(vv{i})}.long_name(:);
  Size=size(vv{i}); Size=num2str(Size);
  Units=nc{name(vv{i})}.units(:);

  sname = repmat(' ',1,LN);
  lname = repmat(' ',1,LLN);
  size_ = repmat(' ',1,LS);
  units = repmat(' ',1,LU);

  lN=min(length(Name),LN);
  lLN=min(length(Long_name),LLN);
  lS=min(length(Size),LS);
  lU=min(length(Units),LU);

  sname(1:lN)  = Name(1:lN);
  lname(1:lLN) = Long_name(1:lLN);
  size_(1:lS)  = Size(1:lS);
  units(1:lU)  = Units(1:lU);

  if show_lname & show_units
    if i==1
      fprintf(fid,'%s\n','[scale(*) offset(*) - Var - Long_Name - Size - Units]');
      fprintf(fid,'%s\n','');
    end
    fprintf(fid,'%s%s %s  %s  %s  %s\n',str1,str2,sname,lname,size_,units);
  elseif show_lname
    if i==1
      fprintf(fid,'%s\n','[scale(*) offset(*) - Var - Long_Name - Size]');
      fprintf(fid,'%s\n','');
    end
    fprintf(fid,'%s%s %s  %s  %s\n',str1,str2,sname,lname,size_);
  elseif show_units
    if i==1
      fprintf(fid,'%s\n','[scale(*) offset(*) - Var -  Size - Units]');
      fprintf(fid,'%s\n','');
    end
    fprintf(fid,'%s%s %s  %s  %s\n',str1,str2,sname,size_,units);
  else
    if i==1
      fprintf(fid,'%s\n','[scale(*) offset(*) - Var - Size]');
      fprintf(fid,'%s\n','');
    end
    fprintf(fid,'%s%s %s  %s\n',str1,str2,sname,size_);
  end

end

nc=close(nc);
fprintf(fid,'%s\n','');
if openf
  fid=fclose(fid);
end
return
