function m_pack(varargin)
%M_PACK   Matlab package by MMA
%   M_PACK(VARARGIN)
%   M_PACK is a matlab package created by Martinho Marta Almeida.
%   It is a collection of m files created during my PhD in Physical
%   Oceanography. It include utilities for many purposes, from
%   harmonic analysis of series to a plot of a simple arrow.
%   Many functions are related with the manipulation of NetCDF data
%   and visualization of input and output files of the ocean model
%   ROMS.
%   The main objective of this function is to add the directories to
%   path in the correct order, so that everything works fine.
%   M_PACK is freely distributed at the site:
%   http://neptuno.fis.ua.pt/~mma
%   For any comments/suggestions use the email:
%   martinho@fis.ua.pt
%   Further information about the contents of M_PACK is available
%   at the site above
%
%   input:
%      VARARGIN:
%         'version'   displays the current M_PACK version
%         'check'     tries to reach a file at the M_PACK site where
%                     latest version is shown. It uses the command
%                     wget, available at least for unix like machines,
%                     I suppose
%         'start',    will add the directories to the pah in the
%                     correct order so that you can start using the
%                     available functions/utilities
%         'stop',     will remove the M_PACK directories from path
%         'help'      will open help from the web. It accepts the
%                     browser executable as the second argument;
%                     by default the browser defined in docopt is used
%         'pdf'       will open a short pdf document with basc
%                     information about the M_PACK. It contains a short
%                     descriptions of all the M_PACK contents.
%                     It accept the executable to
%                     read pdfs as the second argument; by default
%                     'acroread'  is used
%
%   comment:
%      - Without input arguments, this help is shown.
%      - The best way to use this may be to add m_pack('start') to
%        your local startup file.
%      - After realizing that seagrid (Jul-2003) has some problems
%        under some linux, the previous version (Oct-2002) is used.
%        You may try the newest seagrid in you linux machine by making
%        small modifications in this file (change tha variable
%        dirs_seagrid bellow).
%      - About netcdf, windows users must place dlls (netcdf.dll and
%        mexcdf53.dll) in the Matlab \bin and \bin\win32 according
%        to the author.
%
%   example:
%      m_pack('version')     % displays current version
%      m_pack('check')       % check for new version at the web
%      m_pack('start')       % adds M_PACK directories to the path
%      m_pack('stop')        % removes M_PACK from path
%      bin = '~/bin/mozilla'
%      m_pack('help',bin)    % will open the M_PACK site with mozilla
%      bin = 'gv';
%      m_pack('pdf',bin)     % will open the M_PACK pdf reference file
%
%   MMA 4-5-2005, martinho@fis.ua.pt


% about M_PACK version:
this_version = '1.2';
site         = 'http://neptuno.fis.ua.pt/~mma/';
m_pack_dir   = 'm_pack/';

version_info = {
  ['                                                '],
  [' ## M_PACK version ',this_version,'             '],
  ['    - Date:   May 2005                          '],
  ['    - Author: Martinho Marta Almeida            '],
  ['              Physics Department                '],
  ['              Aveiro University, Portugal       '],
  ['    - Web:    ',site,m_pack_dir,'               '],
  ['    - Email;  martinho@fis.ua.pt                '],
  ['                                                ']
};

% about check for new version:
version_url  = [site,m_pack_dir];
version_file = 'm_pack_current_version.txt';
execute      = 'wget';

% about help:
browser = '';

% about pdf:
acroread = 'acroread';
pdf_file = 'm_pack.pdf';


show_version = 0;
check_new    = 0;
show_web     = 0;
start_pack   = 0;
stop_pack    = 0;
show_pdf     = 0;

if nargin == 0
  help m_pack
  return
end

vin = varargin;
for i=1:length(vin)
  if isequal(vin{i},'version')
    show_version = 1;
  end
  if isequal(vin{i},'check')
    check_new = 1;
  end
  if isequal(vin{i},'help')
    show_web = 1;
    eval('browser = vin{i+1};','');
  end
  if isequal(vin{i},'start')
    start_pack = 1;
  end
  if isequal(vin{i},'stop')
    stop_pack = 1;
  end
  if isequal(vin{i},'pdf')
    show_pdf = 1;
    eval('acroread = vin{i+1};','');
  end
end

% --------------------------------------------------------------
% display version
% --------------------------------------------------------------
if show_version
  disp(strvcat(version_info))
end

% --------------------------------------------------------------
% check for new version
% --------------------------------------------------------------
if check_new
  str = [execute,' ',version_url,version_file];
  [status,result] = system(str);
  if status == 0 & ~isequal(computer,'PCWIN')
    ver = load(version_file);
    delete(version_file);
    disp(['## your M_PACK version is ',this_version]);
    disp(['## the latest release available is the version ',num2str(ver)]);
  else
    disp('## unable to check M_PACK version...');
    disp(['## please check it at ',site,m_pack_dir]);
    go = input('  -- do you want to go there now? y=1  \n     ');
    if go
      m_pack('help');
    end
  end
end

% --------------------------------------------------------------
% show web page, help
% --------------------------------------------------------------
if show_web
  if isempty(browser)
    eval(['web ',site,m_pack_dir,' -browser;']);
  else
    [status,result] = system([browser,' ',site,m_pack_dir,' &']);
  end
end

% --------------------------------------------------------------
% show pdf file
% --------------------------------------------------------------
if show_pdf
  % get path:
  m = which('m_pack');
  m = m(1:end-9);
  pdf_file = [m,filesep,'docs',filesep,'pdf_file',filesep,pdf_file];
  if isequal(computer,'PCWIN')
    eval(['! ',pdf_file],'');
  else
    eval(['! ',acroread ,' ',pdf_file],'');
  end
end

% --------------------------------------------------------------
% start and stop M_PACK:
% --------------------------------------------------------------

% get matlab version:
% some paths are different in matlab < 6
v = version;
i=find(version =='R');
v = v(i+1:end);
v(v==')') = '';
v = str2num(v);

if start_pack | stop_pack
  sep = filesep;
  base = which('m_pack');
  base = base(1:end-length('m_pack.m'));

  dirs_m_files  = {
                   ['m_files',sep,'anim'],
                   ['m_files',sep,'img'],
                   ['m_files',sep,'img',sep,'draw_bar'],
                   ['m_files',sep,'roms'],
                   ['m_files',sep,'roms',sep,'roms_ncep'],
                   ['m_files',sep,'roms',sep,'roms_slice'],
                   ['m_files',sep,'roms',sep,'roms_series'],
                   ['m_files',sep,'tools'],
                   ['m_files',sep,'toolsnc'],
                   ['m_files']
                  };

  dirs_spectrha = {
                   ['SpectrHA',sep,'v1',sep,'config'],
                   ['SpectrHA',sep,'v1',sep,'files'],
                   ['SpectrHA',sep,'v1',sep,'help'],
                   ['SpectrHA',sep,'v1'],
                   ['SpectrHA',sep,'v2',sep,'files'],
                   ['SpectrHA',sep,'v2',sep,'modif'],
                   ['SpectrHA',sep,'v2'],
                  };

  dirs_ncdview  = {
                   ['NCDView',sep,'config'],
                   ['NCDView',sep,'datasets'],
                   ['NCDView',sep,'files'],
                   ['NCDView',sep,'help'],
                   ['NCDView'],
                  };


  dirs_rav      = {
                   ['RaV'],
                   ['RaV',sep,'files'],
                  };

  if isequal(computer,'PCWIN')
    dirs_netcdf   = {
                     ['other_authors',sep,'netcdf',sep,'netcdf'],
                     ['other_authors',sep,'netcdf',sep,'netcdf',sep,'ncsource'],
                     ['other_authors',sep,'netcdf',sep,'netcdf',sep,'nctype'],
                     ['other_authors',sep,'netcdf',sep,'netcdf',sep,'ncutility'],
                     ['other_authors',sep,'netcdf',sep,'mexcdf',sep,'pcwin',sep,'PCWIN'],
                    };
  else
    if v >=12
      dirs_netcdf   = {
                       ['other_authors',sep,'netcdf',sep,'netcdf'],
                       ['other_authors',sep,'netcdf',sep,'netcdf',sep,'ncsource'],
                       ['other_authors',sep,'netcdf',sep,'netcdf',sep,'nctype'],
                       ['other_authors',sep,'netcdf',sep,'netcdf',sep,'ncutility'],
                       ['other_authors',sep,'netcdf',sep,'mexcdf',sep,'v6_glx'],
                      };
    else
      dirs_netcdf   = {
                       ['other_authors',sep,'netcdf',sep,'netcdf'],
                       ['other_authors',sep,'netcdf',sep,'netcdf',sep,'ncsource'],
                       ['other_authors',sep,'netcdf',sep,'netcdf',sep,'nctype'],
                       ['other_authors',sep,'netcdf',sep,'netcdf',sep,'ncutility'],
                       ['other_authors',sep,'netcdf',sep,'mexcdf',sep,'v5_glx'],
                      };
    end
  end


  if isequal(computer,'PCWIN')
    if v >=12
      dirs_seagrid  = {
                       ['other_authors',sep,'seagrid',sep,'presto'],
                       ['other_authors',sep,'seagrid',sep,'seagrid_Jul_2003'],
                       ['other_authors',sep,'seagrid',sep,'seagrid_mex',sep,'pcwin_v6'],
                      };
    else
      dirs_seagrid  = {
                       ['other_authors',sep,'seagrid',sep,'presto'],
                       ['other_authors',sep,'seagrid',sep,'seagrid_Jul_2003'],
                       ['other_authors',sep,'seagrid',sep,'seagrid_mex',sep,'pcwin_v5'],
                      };
    end
  else
    dirs_seagrid  = {
                     ['other_authors',sep,'seagrid',sep,'presto'],
                     ['other_authors',sep,'seagrid',sep,'seagrid_Oct_2002'],
                     ['other_authors',sep,'seagrid',sep,'seagrid_mex',sep,'glx'],
                    };
  end


  dirs_tidal_ell={
                   ['other_authors',sep,'tidal_ellipse']
                 };

  dirs_t_tide   = {
                   ['other_authors',sep,'t_tide']
                  };

  dirs_misc     = {
                   ['other_authors',sep,'misc']
                  };


  if start_pack
    % add m_files:
    for i=1:length(dirs_m_files), addpath([base,dirs_m_files{i}]); end
    add{1} = '  --> adding m_files';

    % add ncdview:
    for i=1:length(dirs_ncdview), addpath([base,dirs_ncdview{i}]); end
    add{2} = '  --> adding NCDView';

    % add rav:
    for i=1:length(dirs_rav), addpath([base,dirs_rav{i}]); end
    add{3} = '  --> adding RaV';

    % add spectrha:
    for i=1:length(dirs_spectrha), addpath([base,dirs_spectrha{i}]); end
    add{4} = '  --> adding SpectrHA';

    % add NetCDF:
    for i=1:length(dirs_netcdf), addpath([base,dirs_netcdf{i}]); end
    add{5} = '  --> adding netcdf';

    % add seagrid:
    for i=1:length(dirs_seagrid), addpath([base,dirs_seagrid{i}]); end
    add{6} = '  --> adding seagrid';

    % add t_tide:
    for i=1:length(dirs_t_tide), addpath([base,dirs_t_tide{i}]); end
    add{7} = '  --> adding t_tide';

    % add tidal_ellipse:
    for i=1:length(dirs_tidal_ell), addpath([base,dirs_tidal_ell{i}]); end
    add{8} = '  --> adding tidal_ellipse';

    % add misc:
    for i=1:length(dirs_misc), addpath([base,dirs_misc{i}]); end
    add{9} = '  --> adding misc';


    disp(' ');
    disp(strvcat(add))
    disp(' ');
    disp(['## M_PACK ',this_version,' started']);

  elseif stop_pack
    warning off

    % remove m_files:
    for i=1:length(dirs_m_files), rmpath([base,dirs_m_files{i}]);  end

    % remove ncdview:
    for i=1:length(dirs_ncdview), rmpath([base,dirs_ncdview{i}]); end

    % remove rav:
    for i=1:length(dirs_rav), rmpath([base,dirs_rav{i}]); end

    % remove spectrha:
    for i=1:length(dirs_spectrha), rmpath([base,dirs_spectrha{i}]); end

    % remove NetCDF:
    for i=1:length(dirs_netcdf), rmpath([base,dirs_netcdf{i}]); end

    % remove seagrid:
    for i=1:length(dirs_seagrid), rmpath([base,dirs_seagrid{i}]); end

    % remove t_tide:
    for i=1:length(dirs_t_tide), rmpath([base,dirs_t_tide{i}]); end

    % remove tida_ellipse
    for i=1:length(dirs_tidal_ell), rmpath([base,dirs_tidal_ell{i}]); end

    % remove misc:
    for i=1:length(dirs_misc), rmpath([base,dirs_misc{i}]); end

    disp(' ');
    disp('## M_PACK is stopped');

    warning on
  end
end

function [status,result] = system(str)
% it looks like matlab prior to 6 does not contain system
if isequal(computer,'PCWIN')
  [status,result] = dos(str);
else
  [status,result] = unix(str);
end
